@@ -15,8 +15,9 @@ BEGIN
     IF pg_version_num() >= 90100 THEN
         EXECUTE $E$
             CREATE SCHEMA someschema;
+            CREATE SCHEMA ci_schema;
             CREATE SCHEMA "empty schema";
-            CREATE EXTENSION IF NOT EXISTS citext;
+            CREATE EXTENSION IF NOT EXISTS citext SCHEMA ci_schema;
             CREATE EXTENSION IF NOT EXISTS isn SCHEMA someschema;
             CREATE EXTENSION IF NOT EXISTS ltree SCHEMA someschema;
         $E$;
@@ -38,7 +39,7 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT* FROM check_test(
-            extensions_are( ARRAY['citext', 'isn', 'ltree', 'plpgsql'], 'Got em' ),
+            extensions_are( ARRAY['citext', 'isn', 'ltree', 'plpgsql', 'pgtap'], 'Got em' ),
             true,
             'extensions_are(exts, desc)',
             'Got em',
@@ -46,7 +47,7 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT* FROM check_test(
-            extensions_are( ARRAY['citext', 'isn', 'ltree', 'plpgsql'] ),
+            extensions_are( ARRAY['citext', 'isn', 'ltree', 'plpgsql', 'pgtap'] ),
             true,
             'extensions_are(exts)',
             'Should have the correct extensions',
@@ -54,9 +55,9 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT* FROM check_test(
-            extensions_are( 'public', ARRAY['citext'], 'Got em' ),
+            extensions_are( 'ci_schema', ARRAY['citext'], 'Got em' ),
             true,
-            'extensions_are(public, exts, desc)',
+            'extensions_are(ci_schema, exts, desc)',
             'Got em',
             ''
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
@@ -83,7 +84,7 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT* FROM check_test(
-            extensions_are( ARRAY['citext', 'isn', 'ltree', 'nonesuch'] ),
+            extensions_are( ARRAY['citext', 'isn', 'ltree', 'pgtap', 'nonesuch'] ),
             false,
             'extensions_are(someexts)',
             'Should have the correct extensions',
@@ -98,7 +99,7 @@ BEGIN
         -- 8 tests
     
         FOR tap IN SELECT * FROM check_test(
-            has_extension( 'public', 'citext', 'desc' ),
+            has_extension( 'ci_schema', 'citext', 'desc' ),
             true,
             'has_extension( schema, name, desc )',
             'desc',
@@ -106,10 +107,10 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT * FROM check_test(
-            has_extension( 'public', 'citext'::name ),
+            has_extension( 'ci_schema', 'citext'::name ),
             true,
             'has_extension( schema, name )',
-            'Extension citext should exist in schema public',
+            'Extension citext should exist in schema ci_schema',
             ''
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
@@ -198,7 +199,7 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT * FROM check_test(
-            hasnt_extension( 'public', 'citext', 'desc' ),
+            hasnt_extension( 'ci_schema', 'citext', 'desc' ),
             false,
             'hasnt_extension( schema, name, desc )',
             'desc',
@@ -206,10 +207,10 @@ BEGIN
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
         FOR tap IN SELECT * FROM check_test(
-            hasnt_extension( 'public', 'citext'::name ),
+            hasnt_extension( 'ci_schema', 'citext'::name ),
             false,
             'hasnt_extension( schema, name )',
-            'Extension citext should not exist in schema public',
+            'Extension citext should not exist in schema ci_schema',
             ''
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
 
@@ -264,7 +265,7 @@ BEGIN
         FOR tap IN SELECT * FROM check_test(
             pass('mumble'),
 	        true,
-            'extensions_are(public, exts, desc)',
+            'extensions_are(ci_schema, exts, desc)',
             'mumble',
             ''
         ) AS b LOOP RETURN NEXT tap.b; END LOOP;
