@@ -1,7 +1,8 @@
 \unset ECHO
 \i test/setup.sql
+-- \i sql/pgtap.sql
 
-SELECT plan(1009);
+SELECT plan(1105);
 -- SELECT * FROM no_plan();
 
 CREATE SCHEMA someschema;
@@ -44,6 +45,14 @@ BEGIN
         RETURNS text AS 'SELECT ''anyelement''::text'
         LANGUAGE SQL IMMUTABLE;
     END IF;
+
+    IF pg_version_num() >= 110000 THEN
+        EXECUTE 'CREATE PROCEDURE public.someproc(int) LANGUAGE SQL AS ''''';
+    ELSE
+        CREATE FUNCTION public.someproc(int)
+        RETURNS void AS ''
+        LANGUAGE SQL;
+    END IF;
 END;
 $$;
 
@@ -114,18 +123,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    has_function( 'lower', '{text}'::name[] ),
+    has_function( 'abs', '{int}'::name[] ),
     true,
     'simple function with 1 arg',
-    'Function lower(text) should exist',
+    'Function abs(int) should exist',
     ''
 );
 
 SELECT * FROM check_test(
-    has_function( 'decode', '{text,text}'::name[] ),
+    has_function( 'age', '{timestamptz,timestamptz}'::name[] ),
     true,
     'simple function with 2 args',
-    'Function decode(text, text) should exist',
+    'Function age(timestamptz, timestamptz) should exist',
     ''
 );
 
@@ -207,6 +216,23 @@ SELECT * FROM check_test(
     '' -- No diagnostics.
 );
 
+-- Test with a procedure.
+SELECT * FROM check_test(
+    has_function( 'public', 'someproc', 'hi' ),
+    true,
+    'public procedure',
+    'hi',
+    ''
+);
+
+SELECT * FROM check_test(
+    has_function( 'someproc' ),
+    true,
+    'public procedure',
+    'Function someproc() should exist',
+    ''
+);
+
 /****************************************************************************/
 -- Test hasnt_function().
 SELECT * FROM check_test(
@@ -313,6 +339,23 @@ SELECT * FROM check_test(
     ''
 );
 
+-- Test with a procedure.
+SELECT * FROM check_test(
+    hasnt_function( 'public', 'someproc', 'hi' ),
+    false,
+    'public procedure',
+    'hi',
+    ''
+);
+
+SELECT * FROM check_test(
+    hasnt_function( 'someproc' ),
+    false,
+    'public procedure',
+    'Function someproc() should not exist',
+    ''
+);
+
 /****************************************************************************/
 -- Try can() function names.
 SELECT * FROM check_test(
@@ -374,6 +417,23 @@ SELECT * FROM check_test(
     bar() missing'
 );
 
+-- Try can() with a procedure.
+SELECT * FROM check_test(
+    can( 'public', ARRAY['someproc'], 'whatever' ),
+    true,
+    'can(sch, proc) with desc',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    can( ARRAY['someproc'], 'whatever' ),
+    true,
+    'can(proc) with desc',
+    'whatever',
+    ''
+);
+
 /****************************************************************************/
 -- Test function_lang_is().
 SELECT * FROM check_test(
@@ -393,7 +453,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_lang_is( 'someschema', 'bah', '{"integer", "text"}'::name[], 'plpgsql', 'whatever' ),
+    function_lang_is( 'someschema', 'bah', '{"int", "text"}'::name[], 'plpgsql', 'whatever' ),
     true,
     'function_lang_is(schema, func, args, plpgsql, desc)',
     'whatever',
@@ -401,10 +461,10 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_lang_is( 'someschema', 'bah', '{"integer", "text"}'::name[], 'plpgsql' ),
+    function_lang_is( 'someschema', 'bah', '{"int", "text"}'::name[], 'plpgsql' ),
     true,
     'function_lang_is(schema, func, args, plpgsql)',
-    'Function someschema.bah(integer, text) should be written in plpgsql',
+    'Function someschema.bah(int, text) should be written in plpgsql',
     ''
 );
 
@@ -426,11 +486,11 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_lang_is( 'someschema', 'why', '{"integer", "text"}'::name[], 'plpgsql' ),
+    function_lang_is( 'someschema', 'why', '{"int", "text"}'::name[], 'plpgsql' ),
     false,
     'function_lang_is(schema, func, args, plpgsql)',
-    'Function someschema.why(integer, text) should be written in plpgsql',
-    '    Function someschema.why(integer, text) does not exist'
+    'Function someschema.why(int, text) should be written in plpgsql',
+    '    Function someschema.why(int, text) does not exist'
 );
 
 SELECT * FROM check_test(
@@ -483,7 +543,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_lang_is( 'oww', '{"integer", "text"}'::name[], 'plpgsql', 'whatever' ),
+    function_lang_is( 'oww', '{"int", "text"}'::name[], 'plpgsql', 'whatever' ),
     true,
     'function_lang_is(func, args, plpgsql, desc)',
     'whatever',
@@ -491,10 +551,10 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_lang_is( 'oww', '{"integer", "text"}'::name[], 'plpgsql' ),
+    function_lang_is( 'oww', '{"int", "text"}'::name[], 'plpgsql' ),
     true,
     'function_lang_is(func, args, plpgsql)',
-    'Function oww(integer, text) should be written in plpgsql',
+    'Function oww(int, text) should be written in plpgsql',
     ''
 );
 
@@ -516,11 +576,11 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_lang_is( 'why', '{"integer", "text"}'::name[], 'plpgsql' ),
+    function_lang_is( 'why', '{"int", "text"}'::name[], 'plpgsql' ),
     false,
     'function_lang_is(func, args, plpgsql)',
-    'Function why(integer, text) should be written in plpgsql',
-    '    Function why(integer, text) does not exist'
+    'Function why(int, text) should be written in plpgsql',
+    '    Function why(int, text) does not exist'
 );
 
 SELECT * FROM check_test(
@@ -556,10 +616,27 @@ SELECT * FROM check_test(
     '    Function why() does not exist'
 );
 
+-- Test with procedure.
+SELECT * FROM check_test(
+    function_lang_is( 'public', 'someproc', 'sql', 'whatever' ),
+    true,
+    'function_lang_is(schema, proc, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    function_lang_is( 'someproc', 'sql', 'whatever' ),
+    true,
+    'function_lang_is(schema, proc, desc)',
+    'whatever',
+    ''
+);
+
 /****************************************************************************/
 -- Test function_returns().
 SELECT * FROM check_test(
-    function_returns( 'someschema', 'huh', '{}'::name[], 'boolean', 'whatever' ),
+    function_returns( 'someschema', 'huh', '{}'::name[], 'bool', 'whatever' ),
     true,
     'function_returns(schema, func, 0 args, bool, desc)',
     'whatever',
@@ -575,7 +652,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'someschema', 'bah', ARRAY['integer', 'text'], 'boolean', 'whatever' ),
+    function_returns( 'someschema', 'bah', ARRAY['int', 'text'], 'bool', 'whatever' ),
     true,
     'function_returns(schema, func, args, bool, false)',
     'whatever',
@@ -583,15 +660,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'someschema', 'bah', ARRAY['integer', 'text'], 'boolean' ),
+    function_returns( 'someschema', 'bah', ARRAY['int', 'text'], 'boolean' ),
     true,
     'function_returns(schema, func, args, bool)',
-    'Function someschema.bah(integer, text) should return boolean',
+    'Function someschema.bah(int, text) should return boolean',
     ''
 );
 
 SELECT * FROM check_test(
-    function_returns( 'public', 'pet', '{}'::name[], 'setof boolean', 'whatever' ),
+    function_returns( 'public', 'pet', '{}'::name[], 'setof bool', 'whatever' ),
     true,
     'function_returns(schema, func, 0 args, setof bool, desc)',
     'whatever',
@@ -607,7 +684,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'someschema', 'huh', 'boolean', 'whatever' ),
+    function_returns( 'someschema', 'huh', 'bool', 'whatever' ),
     true,
     'function_returns(schema, func, bool, desc)',
     'whatever',
@@ -623,7 +700,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'someschema', 'bah', 'boolean', 'whatever' ),
+    function_returns( 'someschema', 'bah', 'bool', 'whatever' ),
     true,
     'function_returns(schema, other func, bool, false)',
     'whatever',
@@ -639,7 +716,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'public', 'pet', 'setof boolean', 'whatever' ),
+    function_returns( 'public', 'pet', 'setof bool', 'whatever' ),
     true,
     'function_returns(schema, func, setof bool, desc)',
     'whatever',
@@ -655,7 +732,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'yay', '{}'::name[], 'boolean', 'whatever' ),
+    function_returns( 'yay', '{}'::name[], 'bool', 'whatever' ),
     true,
     'function_returns(func, 0 args, bool, desc)',
     'whatever',
@@ -671,7 +748,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'oww', ARRAY['integer', 'text'], 'boolean', 'whatever' ),
+    function_returns( 'oww', ARRAY['int', 'text'], 'bool', 'whatever' ),
     true,
     'function_returns(func, args, bool, false)',
     'whatever',
@@ -679,15 +756,15 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'oww', ARRAY['integer', 'text'], 'boolean' ),
+    function_returns( 'oww', ARRAY['int', 'text'], 'boolean' ),
     true,
     'function_returns(func, args, bool)',
-    'Function oww(integer, text) should return boolean',
+    'Function oww(int, text) should return boolean',
     ''
 );
 
 SELECT * FROM check_test(
-    function_returns( 'pet', '{}'::name[], 'setof boolean', 'whatever' ),
+    function_returns( 'pet', '{}'::name[], 'setof bool', 'whatever' ),
     true,
     'function_returns(func, 0 args, setof bool, desc)',
     'whatever',
@@ -703,7 +780,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'yay', 'boolean', 'whatever' ),
+    function_returns( 'yay', 'bool', 'whatever' ),
     true,
     'function_returns(func, bool, desc)',
     'whatever',
@@ -719,7 +796,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'oww', 'boolean', 'whatever' ),
+    function_returns( 'oww', 'bool', 'whatever' ),
     true,
     'function_returns(other func, bool, false)',
     'whatever',
@@ -735,7 +812,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    function_returns( 'pet', 'setof boolean', 'whatever' ),
+    function_returns( 'pet', 'setof bool', 'whatever' ),
     true,
     'function_returns(func, setof bool, desc)',
     'whatever',
@@ -750,6 +827,23 @@ SELECT * FROM check_test(
     ''
 );
 
+-- Try with a procedure.
+SELECT * FROM check_test(
+    function_returns( 'public', 'someproc'::name, 'void' ),
+    true,
+    'function_returns(sch, proc, void)',
+    'Function public.someproc() should return void',
+    ''
+);
+
+SELECT * FROM check_test(
+    function_returns( 'someproc'::name, 'void' ),
+    true,
+    'function_returns(sch, proc, void)',
+    'Function someproc() should return void',
+    ''
+);
+
 /****************************************************************************/
 -- Test is_definer() isnt_definer().
 SELECT * FROM check_test(
@@ -785,7 +879,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_definer( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_definer(schema, func, args, desc)',
     'whatever',
@@ -793,7 +887,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_definer( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_definer(schema, func, args, desc)',
     'whatever',
@@ -801,18 +895,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
+    is_definer( 'public', 'oww', ARRAY['int', 'text'] ),
     false,
     'is_definer(schema, func, args)',
-    'Function public.oww(integer, text) should be security definer',
+    'Function public.oww(int, text) should be security definer',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
+    isnt_definer( 'public', 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_definer(schema, func, args)',
-    'Function public.oww(integer, text) should not be security definer',
+    'Function public.oww(int, text) should not be security definer',
     ''
 );
 
@@ -881,7 +975,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_definer( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_definer(schema, func, args, desc)',
     'whatever',
@@ -889,7 +983,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_definer( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_definer(schema, func, args, desc)',
     'whatever',
@@ -897,18 +991,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
+    is_definer( 'public', 'oww', ARRAY['int', 'text'] ),
     false,
     'is_definer(schema, func, args)',
-    'Function public.oww(integer, text) should be security definer',
+    'Function public.oww(int, text) should be security definer',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
+    isnt_definer( 'public', 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_definer(schema, func, args)',
-    'Function public.oww(integer, text) should not be security definer',
+    'Function public.oww(int, text) should not be security definer',
     ''
 );
 
@@ -977,7 +1071,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_definer( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_definer( 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_definer(func, args, desc)',
     'whatever',
@@ -985,7 +1079,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_definer( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_definer( 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_definer(func, args, desc)',
     'whatever',
@@ -993,18 +1087,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_definer( 'oww', ARRAY['integer', 'text'] ),
+    is_definer( 'oww', ARRAY['int', 'text'] ),
     false,
     'is_definer(func, args)',
-    'Function oww(integer, text) should be security definer',
+    'Function oww(int, text) should be security definer',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_definer( 'oww', ARRAY['integer', 'text'] ),
+    isnt_definer( 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_definer(func, args)',
-    'Function oww(integer, text) should not be security definer',
+    'Function oww(int, text) should not be security definer',
     ''
 );
 
@@ -1040,6 +1134,39 @@ SELECT * FROM check_test(
     ''
 );
 
+-- Try with a procedure.
+SELECT * FROM check_test(
+    is_definer( 'public'::name, 'someproc'::name ),
+    false,
+    'is_definer(sch, proc)',
+    'Function public.someproc() should be security definer',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_definer( 'public'::name, 'someproc'::name ),
+    true,
+    'isnt_definer(sch, proc)',
+    'Function public.someproc() should not be security definer',
+    ''
+);
+
+SELECT * FROM check_test(
+    is_definer( 'someproc'::name ),
+    false,
+    'is_definer(proc)',
+    'Function someproc() should be security definer',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_definer( 'someproc'::name ),
+    true,
+    'isnt_definer(proc)',
+    'Function someproc() should not be security definer',
+    ''
+);
+
 /****************************************************************************/
 -- Test is_normal_function() and isnt_normal_function().
 
@@ -1078,7 +1205,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_normal_function( 'someschema', 'bah', ARRAY['integer', 'text'], 'whatever' ),
+    is_normal_function( 'someschema', 'bah', ARRAY['int', 'text'], 'whatever' ),
     true,
     'is_normal_function(schema, func, args, desc)',
     'whatever',
@@ -1094,7 +1221,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_normal_function( 'someschema', 'bah', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_normal_function( 'someschema', 'bah', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_normal_function(schema, func, args, desc)',
     'whatever',
@@ -1161,18 +1288,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_normal_function( 'someschema', 'bah', ARRAY['integer', 'text'] ),
+    is_normal_function( 'someschema', 'bah', ARRAY['int', 'text'] ),
     true,
     'is_normal_function(schema, func2, args)',
-    'Function someschema.bah(integer, text) should be a normal function',
+    'Function someschema.bah(int, text) should be a normal function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_normal_function( 'someschema', 'bah', ARRAY['integer', 'text'] ),
+    isnt_normal_function( 'someschema', 'bah', ARRAY['int', 'text'] ),
     false,
     'isnt_normal_function(schema, func2, args)',
-    'Function someschema.bah(integer, text) should not be a normal function',
+    'Function someschema.bah(int, text) should not be a normal function',
     ''
 );
 
@@ -1363,7 +1490,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_normal_function( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_normal_function( 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'is_normal_function(func, args, desc)',
     'whatever',
@@ -1371,7 +1498,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_normal_function( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_normal_function( 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'isnt_normal_function(func, args, desc)',
     'whatever',
@@ -1414,18 +1541,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_normal_function( 'oww', ARRAY['integer', 'text'] ),
+    is_normal_function( 'oww', ARRAY['int', 'text'] ),
     true,
     'is_normal_function(func, noargs)',
-    'Function oww(integer, text) should be a normal function',
+    'Function oww(int, text) should be a normal function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_normal_function( 'oww', ARRAY['integer', 'text'] ),
+    isnt_normal_function( 'oww', ARRAY['int', 'text'] ),
     false,
     'isnt_normal_function(func, noargs)',
-    'Function oww(integer, text) should not be a normal function',
+    'Function oww(int, text) should not be a normal function',
     ''
 );
 
@@ -1580,6 +1707,43 @@ SELECT * FROM check_test(
     '    Function zippo() does not exist'
 );
 
+CREATE FUNCTION proc_name() RETURNS TEXT LANGUAGE SQL AS $$
+    -- Use an aggregate function in place of the proc on v10 and earlier.
+    SELECT CASE WHEN pg_version_num() >= 110000 THEN 'someproc' ELSE 'tap_accum' END;
+$$;
+
+SELECT * FROM check_test(
+    is_normal_function( 'public', proc_name()::name ),
+    false,
+    'is_normal_function(schema, proc)',
+    format('Function public.%s() should be a normal function', proc_name()),
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_normal_function( 'public', proc_name()::name ),
+    true,
+    'isnt_normal_function(schema, proc)',
+    format('Function public.%s() should not be a normal function', proc_name()),
+    ''
+);
+
+SELECT * FROM check_test(
+    is_normal_function( proc_name()::name ),
+    false,
+    'is_normal_function(proc)',
+    format('Function %s() should be a normal function', proc_name()),
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_normal_function( proc_name()::name ),
+    true,
+    'isnt_normal_function(proc)',
+    format('Function %s() should not be a normal function', proc_name()),
+    ''
+);
+
 /****************************************************************************/
 -- Test is_aggregate() and isnt_aggregate().
 
@@ -1602,7 +1766,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_aggregate( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_aggregate( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_aggregate(schema, func, args, desc)',
     'whatever',
@@ -1610,7 +1774,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_aggregate( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_aggregate( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_aggregate(schema, func, args, desc)',
     'whatever',
@@ -1653,18 +1817,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_aggregate( 'public', 'oww', ARRAY['integer', 'text'] ),
+    is_aggregate( 'public', 'oww', ARRAY['int', 'text'] ),
     false,
     'is_aggregate(schema, func, args)',
-    'Function public.oww(integer, text) should be an aggregate function',
+    'Function public.oww(int, text) should be an aggregate function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_aggregate( 'public', 'oww', ARRAY['integer', 'text'] ),
+    isnt_aggregate( 'public', 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_aggregate(schema, func, args)',
-    'Function public.oww(integer, text) should not be an aggregate function',
+    'Function public.oww(int, text) should not be an aggregate function',
     ''
 );
 
@@ -1774,7 +1938,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_aggregate( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_aggregate( 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_aggregate(func, args, desc)',
     'whatever',
@@ -1782,7 +1946,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_aggregate( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_aggregate( 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_aggregate(func, args, desc)',
     'whatever',
@@ -1825,18 +1989,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_aggregate( 'oww', ARRAY['integer', 'text'] ),
+    is_aggregate( 'oww', ARRAY['int', 'text'] ),
     false,
     'is_aggregate(func, args)',
-    'Function oww(integer, text) should be an aggregate function',
+    'Function oww(int, text) should be an aggregate function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_aggregate( 'oww', ARRAY['integer', 'text'] ),
+    isnt_aggregate( 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_aggregate(func, args)',
-    'Function oww(integer, text) should not be an aggregate function',
+    'Function oww(int, text) should not be an aggregate function',
     ''
 );
 
@@ -1927,13 +2091,46 @@ SELECT * FROM check_test(
     '    Function nope() does not exist'
 );
 
+-- Try with a procedure.
+SELECT * FROM check_test(
+    is_aggregate( 'public', 'someproc'::name ),
+    false,
+    'is_aggregate(schema, proc)',
+    'Function public.someproc() should be an aggregate function',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'someproc'::name ),
+    true,
+    'is_aggregate(schema, proc)',
+    'Function public.someproc() should not be an aggregate function',
+    ''
+);
+
+SELECT * FROM check_test(
+    is_aggregate( 'someproc' ),
+    false,
+    'is_aggregate(proc)',
+    'Function someproc() should be an aggregate function',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_aggregate( 'someproc' ),
+    true,
+    'is_aggregate(proc)',
+    'Function someproc() should not be an aggregate function',
+    ''
+);
+
 /****************************************************************************/
 -- Test is_window() and isnt_window().
 
 -- is_window ( NAME, NAME, NAME[], TEXT )
 -- isnt_window ( NAME, NAME, NAME[], TEXT )
 SELECT * FROM check_test(
-    is_window( 'pg_catalog', 'ntile', ARRAY['integer'], 'whatever' ),
+    is_window( 'pg_catalog', 'ntile', ARRAY['int'], 'whatever' ),
     true,
     'is_window(schema, win, arg, desc)',
     'whatever',
@@ -1941,7 +2138,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'pg_catalog', 'ntile', ARRAY['integer'], 'whatever' ),
+    isnt_window( 'pg_catalog', 'ntile', ARRAY['int'], 'whatever' ),
     false,
     'isnt_window(schema, win, arg, desc)',
     'whatever',
@@ -1949,7 +2146,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_window( 'someschema', 'bah', ARRAY['integer', 'text'], 'whatever' ),
+    is_window( 'someschema', 'bah', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_window(schema, func, arg, desc)',
     'whatever',
@@ -1957,7 +2154,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'someschema', 'bah', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_window( 'someschema', 'bah', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_window(schema, func, arg, desc)',
     'whatever',
@@ -1998,52 +2195,52 @@ SELECT * FROM check_test(
 
 -- Test diagnostics
 SELECT * FROM check_test(
-    is_window( 'someschema', 'nope', ARRAY['integer'], 'whatever' ),
+    is_window( 'someschema', 'nope', ARRAY['int'], 'whatever' ),
     false,
     'is_window(schema, nowin, arg, desc)',
     'whatever',
-    '    Function someschema.nope(integer) does not exist'
+    '    Function someschema.nope(int) does not exist'
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'someschema', 'nope', ARRAY['integer'], 'whatever' ),
+    isnt_window( 'someschema', 'nope', ARRAY['int'], 'whatever' ),
     false,
     'isnt_window(schema, nowin, arg, desc)',
     'whatever',
-    '    Function someschema.nope(integer) does not exist'
+    '    Function someschema.nope(int) does not exist'
 );
 
 -- is_window ( NAME, NAME, NAME[] )
 -- isnt_window ( NAME, NAME, NAME[] )
 SELECT * FROM check_test(
-    is_window( 'pg_catalog', 'ntile', ARRAY['integer'] ),
+    is_window( 'pg_catalog', 'ntile', ARRAY['int'] ),
     true,
     'is_window(schema, win, arg)',
-    'Function pg_catalog.ntile(integer) should be a window function',
+    'Function pg_catalog.ntile(int) should be a window function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'pg_catalog', 'ntile', ARRAY['integer'] ),
+    isnt_window( 'pg_catalog', 'ntile', ARRAY['int'] ),
     false,
     'isnt_window(schema, win, arg)',
-    'Function pg_catalog.ntile(integer) should not be a window function',
+    'Function pg_catalog.ntile(int) should not be a window function',
     ''
 );
 
 SELECT * FROM check_test(
-    is_window( 'someschema', 'bah', ARRAY['integer', 'text'] ),
+    is_window( 'someschema', 'bah', ARRAY['int', 'text'] ),
     false,
     'is_window(schema, func, arg)',
-    'Function someschema.bah(integer, text) should be a window function',
+    'Function someschema.bah(int, text) should be a window function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'someschema', 'bah', ARRAY['integer', 'text'] ),
+    isnt_window( 'someschema', 'bah', ARRAY['int', 'text'] ),
     true,
     'isnt_window(schema, func, arg)',
-    'Function someschema.bah(integer, text) should not be a window function',
+    'Function someschema.bah(int, text) should not be a window function',
     ''
 );
 
@@ -2081,19 +2278,19 @@ SELECT * FROM check_test(
 
 -- Test diagnostics
 SELECT * FROM check_test(
-    is_window( 'someschema', 'nada', ARRAY['integer'] ),
+    is_window( 'someschema', 'nada', ARRAY['int'] ),
     false,
     'is_window(schema, nowin, arg)',
-    'Function someschema.nada(integer) should be a window function',
-    '    Function someschema.nada(integer) does not exist'
+    'Function someschema.nada(int) should be a window function',
+    '    Function someschema.nada(int) does not exist'
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'someschema', 'nada', ARRAY['integer'] ),
+    isnt_window( 'someschema', 'nada', ARRAY['int'] ),
     false,
     'isnt_window(schema, nowin, arg)',
-    'Function someschema.nada(integer) should not be a window function',
-    '    Function someschema.nada(integer) does not exist'
+    'Function someschema.nada(int) should not be a window function',
+    '    Function someschema.nada(int) does not exist'
 );
 
 -- is_window ( NAME, NAME, TEXT )
@@ -2217,7 +2414,7 @@ SELECT * FROM check_test(
 -- is_window ( NAME, NAME[], TEXT )
 -- isnt_window ( NAME, NAME[], TEXT )
 SELECT * FROM check_test(
-    is_window( 'ntile', ARRAY['integer'], 'whatever' ),
+    is_window( 'ntile', ARRAY['int'], 'whatever' ),
     true,
     'is_window(win, arg, desc)',
     'whatever',
@@ -2225,7 +2422,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'ntile', ARRAY['integer'], 'whatever' ),
+    isnt_window( 'ntile', ARRAY['int'], 'whatever' ),
     false,
     'isnt_window(win, arg, desc)',
     'whatever',
@@ -2233,7 +2430,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_window( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_window( 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_window(func, arg, desc)',
     'whatever',
@@ -2241,7 +2438,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_window( 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_window(func, arg, desc)',
     'whatever',
@@ -2282,52 +2479,52 @@ SELECT * FROM check_test(
 
 -- Test diagnostics
 SELECT * FROM check_test(
-    is_window( 'nada', ARRAY['integer'], 'whatever' ),
+    is_window( 'nada', ARRAY['int'], 'whatever' ),
     false,
     'is_window(nowin, arg, desc)',
     'whatever',
-    '    Function nada(integer) does not exist'
+    '    Function nada(int) does not exist'
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'nada', ARRAY['integer'], 'whatever' ),
+    isnt_window( 'nada', ARRAY['int'], 'whatever' ),
     false,
     'isnt_window(nowin, arg, desc)',
     'whatever',
-    '    Function nada(integer) does not exist'
+    '    Function nada(int) does not exist'
 );
 
 -- is_window( NAME, NAME[] )
 -- isnt_window( NAME, NAME[] )
 SELECT * FROM check_test(
-    is_window( 'ntile', ARRAY['integer'] ),
+    is_window( 'ntile', ARRAY['int'] ),
     true,
     'is_window(win, arg, desc)',
-    'Function ntile(integer) should be a window function',
+    'Function ntile(int) should be a window function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'ntile', ARRAY['integer'] ),
+    isnt_window( 'ntile', ARRAY['int'] ),
     false,
     'isnt_window(win, arg, desc)',
-    'Function ntile(integer) should not be a window function',
+    'Function ntile(int) should not be a window function',
     ''
 );
 
 SELECT * FROM check_test(
-    is_window( 'oww', ARRAY['integer', 'text'] ),
+    is_window( 'oww', ARRAY['int', 'text'] ),
     false,
     'is_window(func, arg, desc)',
-    'Function oww(integer, text) should be a window function',
+    'Function oww(int, text) should be a window function',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'oww', ARRAY['integer', 'text'] ),
+    isnt_window( 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_window(func, arg, desc)',
-    'Function oww(integer, text) should not be a window function',
+    'Function oww(int, text) should not be a window function',
     ''
 );
 
@@ -2365,19 +2562,19 @@ SELECT * FROM check_test(
 
 -- Test diagnostics
 SELECT * FROM check_test(
-    is_window( 'nope', ARRAY['integer'] ),
+    is_window( 'nope', ARRAY['int'] ),
     false,
     'is_window(nowin, arg, desc)',
-    'Function nope(integer) should be a window function',
-    '    Function nope(integer) does not exist'
+    'Function nope(int) should be a window function',
+    '    Function nope(int) does not exist'
 );
 
 SELECT * FROM check_test(
-    isnt_window( 'nope', ARRAY['integer'] ),
+    isnt_window( 'nope', ARRAY['int'] ),
     false,
     'isnt_window(nowin, arg, desc)',
-    'Function nope(integer) should not be a window function',
-    '    Function nope(integer) does not exist'
+    'Function nope(int) should not be a window function',
+    '    Function nope(int) does not exist'
 );
 
 -- is_window( NAME, TEXT )
@@ -2490,6 +2687,39 @@ SELECT * FROM check_test(
     '    Function nooo() does not exist'
 );
 
+-- Try with a procedure.
+SELECT * FROM check_test(
+    is_window( 'public', 'someproc'::name ),
+    false,
+    'is_window(schema, proc)',
+    'Function public.someproc() should be a window function',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_window( 'public', 'someproc'::name ),
+    true,
+    'is_window(schema, proc)',
+    'Function public.someproc() should not be a window function',
+    ''
+);
+
+SELECT * FROM check_test(
+    is_window( 'someproc' ),
+    false,
+    'is_window(proc)',
+    'Function someproc() should be a window function',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_window( 'someproc' ),
+    true,
+    'is_window(proc)',
+    'Function someproc() should not be a window function',
+    ''
+);
+
 /****************************************************************************/
 -- Test is_strict() and isnt_strict().
 SELECT * FROM check_test(
@@ -2525,7 +2755,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_strict( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_strict( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_strict(schema, func, args, desc)',
     'whatever',
@@ -2533,7 +2763,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_strict( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_strict( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_strict(schema, func, args, desc)',
     'whatever',
@@ -2541,18 +2771,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_strict( 'public', 'oww', ARRAY['integer', 'text'] ),
+    is_strict( 'public', 'oww', ARRAY['int', 'text'] ),
     false,
     'is_strict(schema, func, args)',
-    'Function public.oww(integer, text) should be strict',
+    'Function public.oww(int, text) should be strict',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_strict( 'public', 'oww', ARRAY['integer', 'text'] ),
+    isnt_strict( 'public', 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_strict(schema, func, args)',
-    'Function public.oww(integer, text) should not be strict',
+    'Function public.oww(int, text) should not be strict',
     ''
 );
 
@@ -2589,7 +2819,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_strict( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_strict( 'public', 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_strict(schema, func, args, desc)',
     'whatever',
@@ -2597,10 +2827,10 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_strict( 'public', 'oww', ARRAY['integer', 'text'] ),
+    isnt_strict( 'public', 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_strict(schema, func, args)',
-    'Function public.oww(integer, text) should not be strict',
+    'Function public.oww(int, text) should not be strict',
     ''
 );
 
@@ -2637,7 +2867,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_strict( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    is_strict( 'oww', ARRAY['int', 'text'], 'whatever' ),
     false,
     'is_strict(func, args, desc)',
     'whatever',
@@ -2645,7 +2875,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    isnt_strict( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    isnt_strict( 'oww', ARRAY['int', 'text'], 'whatever' ),
     true,
     'isnt_strict(func, args, desc)',
     'whatever',
@@ -2653,18 +2883,18 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    is_strict( 'oww', ARRAY['integer', 'text'] ),
+    is_strict( 'oww', ARRAY['int', 'text'] ),
     false,
     'is_strict(func, args)',
-    'Function oww(integer, text) should be strict',
+    'Function oww(int, text) should be strict',
     ''
 );
 
 SELECT * FROM check_test(
-    isnt_strict( 'oww', ARRAY['integer', 'text'] ),
+    isnt_strict( 'oww', ARRAY['int', 'text'] ),
     true,
     'isnt_strict(func, args)',
-    'Function oww(integer, text) should not be strict',
+    'Function oww(int, text) should not be strict',
     ''
 );
 
@@ -2700,6 +2930,39 @@ SELECT * FROM check_test(
     ''
 );
 
+-- Try a procedure (never strict).
+SELECT * FROM check_test(
+    is_strict( 'public', 'someproc'::name ),
+    false,
+    'is_strict(sch, proc)',
+    'Function public.someproc() should be strict',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_strict( 'public', 'someproc'::name ),
+    true,
+    'isnt_strict(sch, proc)',
+    'Function public.someproc() should not be strict',
+    ''
+);
+
+SELECT * FROM check_test(
+    is_strict( 'someproc'::name ),
+    false,
+    'is_strict(proc)',
+    'Function someproc() should be strict',
+    ''
+);
+
+SELECT * FROM check_test(
+    isnt_strict( 'someproc'::name ),
+    true,
+    'isnt_strict(proc)',
+    'Function someproc() should not be strict',
+    ''
+);
+
 /****************************************************************************/
 -- Test volatility_is().
 SELECT * FROM check_test(
@@ -2719,7 +2982,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    volatility_is( 'public', 'oww', ARRAY['integer', 'text'], 'immutable', 'whatever' ),
+    volatility_is( 'public', 'oww', ARRAY['int', 'text'], 'immutable', 'whatever' ),
     true,
     'function_volatility(schema, func, args, immutable, desc)',
     'whatever',
@@ -2743,10 +3006,10 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    volatility_is( 'public', 'oww', ARRAY['integer', 'text'], 'immutable' ),
+    volatility_is( 'public', 'oww', ARRAY['int', 'text'], 'immutable' ),
     true,
     'function_volatility(schema, func, args, immutable)',
-    'Function public.oww(integer, text) should be IMMUTABLE'
+    'Function public.oww(int, text) should be IMMUTABLE'
     ''
 );
 
@@ -2799,7 +3062,7 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    volatility_is( 'oww', ARRAY['integer', 'text'], 'immutable', 'whatever' ),
+    volatility_is( 'oww', ARRAY['int', 'text'], 'immutable', 'whatever' ),
     true,
     'function_volatility(func, args, immutable, desc)',
     'whatever',
@@ -2823,10 +3086,10 @@ SELECT * FROM check_test(
 );
 
 SELECT * FROM check_test(
-    volatility_is( 'oww', ARRAY['integer', 'text'], 'immutable' ),
+    volatility_is( 'oww', ARRAY['int', 'text'], 'immutable' ),
     true,
     'function_volatility(func, args, immutable)',
-    'Function oww(integer, text) should be IMMUTABLE'
+    'Function oww(int, text) should be IMMUTABLE'
     ''
 );
 
@@ -2862,6 +3125,23 @@ SELECT * FROM check_test(
     ''
 );
 
+-- Test a procedure (always volatile)
+SELECT * FROM check_test(
+    volatility_is( 'public', 'someproc'::name, 'volatile' ),
+    true,
+    'function_volatility(sch, proc, volatile)',
+    'Function public.someproc() should be VOLATILE',
+    ''
+);
+
+SELECT * FROM check_test(
+    volatility_is( 'someproc'::name, 'volatile' ),
+    true,
+    'function_volatility(proc, volatile)',
+    'Function someproc() should be VOLATILE',
+    ''
+);
+
 /****************************************************************************/
 -- Finish the tests and clean up.
 SELECT * FROM finish();
